@@ -468,6 +468,11 @@ public class A3Canvas extends Canvas3D implements A3CanvasInterface {
     public A3Object pickA3(int x,int y) {
         return universe.pickA3(x,y);
     }
+
+    @Override
+    public A3Object pick(Vector3d origin,Vector3d dir) {
+        return universe.pick(origin,dir);
+    }
 //  ----------J3DGraphics2D(文字描画など)---------
     @Override
     public void add(Component2D c) {
@@ -1053,4 +1058,8 @@ public class A3Canvas extends Canvas3D implements A3CanvasInterface {
     public void setVirtualUniverse(A3VirtualUniverse vu) {
         // TODO Version3系列ではこのメソッドが削除できるようにすべし。
     }
+    @Override
+    public A3VirtualUniverse getVirtualUniverse() {
+        return universe;
+    }
 }
