@@ -507,8 +507,16 @@ public interface A3CanvasInterface {
 
     /**
      * A3Canvas上の点(x,y)にあるA3Objectをピックアップします。
+     * なにもオブジェクトが無い場合にはnullを返します。
      */
     public A3Object pickA3(int x,int y);
+
+    /**
+     * 仮想空間の座標系においてoriginで指定した位置からdirで指定した
+     * 方向に半直線を延し、その半直線上にある一番近いA3Objectを返します。
+     * なにもオブジェクトが無い場合にはnullを返します。
+     */
+    public A3Object pick(Vector3d origin,Vector3d dir);
 //  ----------J3DGraphics2D(文字描画など)---------
     /**
      * A3Canvasに2Dの描画を行うためのComponent2Dを登録します。
@@ -1049,4 +1057,10 @@ public interface A3CanvasInterface {
      * ライブラリ内部で仕様する物なので利用しないで下さい．
      */
     public void setVirtualUniverse(A3VirtualUniverse vu);
+
+    /**
+     * セットされているA3VirtualUniverseを返すメソッドですが，
+     * ライブラリ内部で仕様する物なので利用しないで下さい．
+     */
+    public A3VirtualUniverse getVirtualUniverse();
 }
