@@ -51,6 +51,8 @@ class A3VirtualUniverse extends VirtualUniverse implements A3CanvasInterface {
             init(((JA3Canvas)canvas).getOffscreenCanvas3D());
         else if (canvas instanceof A3Widget)
             init(((A3Widget)canvas).tCanvas.getOffscreenCanvas3D());
+        else if (canvas instanceof JA3Canvas2)
+            init(((JA3Canvas2)canvas).getOffscreenCanvas3D());
     }
     void init(Canvas3D c3d) {
         canvas3d = c3d;
@@ -634,6 +636,11 @@ class A3VirtualUniverse extends VirtualUniverse implements A3CanvasInterface {
     public A3Object pickA3(int x,int y) {
         return pickingBehavior.pickA3(x,y);
     }
+
+    @Override
+    public A3Object pick(Vector3d origin,Vector3d dir) {
+        return pickingBehavior.pickA3(origin,dir);
+    }
 //  ----------シーン関係のメソッド---------
     @Override
     public void prepareScene(int scene) {
@@ -1452,6 +1459,11 @@ class A3VirtualUniverse extends VirtualUniverse implements A3CanvasInterface {
         
     }
 
+    @Override
+    public A3VirtualUniverse getVirtualUniverse() {
+        return this;
+    }
+
     /**
      * 引数のA3Objectを強調表示にします。
      */
