@@ -30,8 +30,8 @@ public class A3Widget extends JFrame implements A3CanvasInterface {
         setDefaultCloseOperation(WindowConstants.EXIT_ON_CLOSE);
         setBounds(0,0,w,h);
 
-        tCanvas = new TransCanvas3D();
-        tCanvas.widget = this;
+        tCanvas = new TransCanvas3D(true);
+        tCanvas.canvasIF = this;
         tCanvas.setResizeMode(TransCanvas3D.RESIZE_IMMEDIATELY);
         this.add("Center",tCanvas);
         Dimension dim = new Dimension(w,h);
@@ -475,6 +475,11 @@ public class A3Widget extends JFrame implements A3CanvasInterface {
     public A3Object pickA3(int x,int y) {
         return universe.pickingBehavior.pickA3(x,y);
     }
+
+    @Override
+    public A3Object pick(Vector3d origin,Vector3d dir) {
+        return universe.pickingBehavior.pickA3(origin,dir);
+    }
 //  ----------J3DGraphics2D(文字描画など)---------
     @Override
     public void add(Component2D c) {
@@ -1120,4 +1125,9 @@ public class A3Widget extends JFrame implements A3CanvasInterface {
         // TODO Version3系列ではこのメソッドが削除できるようにすべし。
         
     }
+
+    @Override
+    public A3VirtualUniverse getVirtualUniverse() {
+        return universe;
+    }
 }
