@@ -451,6 +451,11 @@ public class A3Window extends JFrame implements A3CanvasInterface {
         return canvas.pickA3(x,y);
     }
 
+    @Override
+    public A3Object pick(Vector3d origin,Vector3d dir) {
+        return canvas.pick(origin,dir);
+    }
+
     @Override
     public int getFPS() {
         return canvas.getFPS();
@@ -978,4 +983,9 @@ public class A3Window extends JFrame implements A3CanvasInterface {
         // TODO Version3系列ではこのメソッドが削除できるようにすべし。
         
     }
+
+    @Override
+    public A3VirtualUniverse getVirtualUniverse() {
+        return canvas.getVirtualUniverse();
+    }
 }
