@@ -245,8 +245,14 @@ class ActionBehavior extends Behavior implements Cloneable {
                 } else {
                     TransformGroup tg = a.tgMap.get(boneName);
                     Transform3D t = a.motion.getTransform3D(boneName,timeD);
-                    if (t!=null)
-                        tg.setTransform(t);
+                    if (t!=null) {
+                        try {
+                            tg.setTransform(t);
+                        } catch(BadTransformException e) {
+                            System.out.println("BadTransformException in ActionBehavior.processStimulus().");
+                            //e.printStackTrace();
+                        }
+                    }
                 }
             }
             //3Dセレクトマーカーのアジャストメント
