@@ -475,6 +475,11 @@ public class JA3Canvas extends JCanvas3D implements A3CanvasInterface {
     public A3Object pickA3(int x,int y) {
         return universe.pickingBehavior.pickA3(x,y);
     }
+
+    @Override
+    public A3Object pick(Vector3d origin,Vector3d dir) {
+        return universe.pickingBehavior.pickA3(origin,dir);
+    }
 //  ----------J3DGraphics2D(文字描画など)---------
     @Override
     public void add(Component2D c) {
@@ -1067,4 +1072,8 @@ public class JA3Canvas extends JCanvas3D implements A3CanvasInterface {
         // TODO Version3系列ではこのメソッドが削除できるようにすべし。
         
     }
+    @Override
+    public A3VirtualUniverse getVirtualUniverse() {
+        return universe;
+    }
 }
