@@ -5,6 +5,15 @@ package jp.sourceforge.acerola3d.a3;
  * ファイルをベースにしています．
  * クラス名をJCanvas3DからTransCanvas3Dにかえた以外の
  * 変更をした所には//kenjiと書いときます．
+ * 
+ * (2011,03/08)
+ * もともとA3Widgetで背景が透明な3D表示をさせるのが目的のクラスでしたが、
+ * JA3Canvas2(上手くいったらJA3Canvasに置き換えるかもしれない)でも使える
+ * ように拡張することにします。具体的には、背景を透明化するかどうかを設定・
+ * 変更可能にし、3D描画を実際に出力する前に、フィルター処理ができるように
+ * する拡張を入れる。
+ * それから，いまさらだけどベースにしたJCanvas3DはJava3D 1.5.2と考えても
+ * 問題ないっぽい．
  */
 /*
  * $RCSfile: JCanvas3D.java,v $
@@ -65,6 +74,7 @@ import java.awt.Rectangle;
 import java.awt.image.BufferedImage;
 import java.lang.reflect.InvocationTargetException;
 import java.util.Arrays; //kenji
+import java.util.ArrayList; //kenji
 
 import javax.media.j3d.Canvas3D;
 import javax.media.j3d.GraphicsConfigTemplate3D;
@@ -171,7 +181,9 @@ class TransCanvas3D extends JPanel implements AncestorListener {
     private GraphicsDevice device;
 
     //kenji
-    A3Widget widget = null;
+    A3CanvasInterface canvasIF = null;
+    //kenji
+    boolean trans = false;
 
     //TODO: FBA: the constructor below should be callable. Code should be changed so that it is possible, in order for the canvas to be useable into netbeans.
     //TODO: FBA: create a netbeans module that installs J3D as a library and the TransCanvas3D as a new item in a new J3D category of the swing palette (take from the java.net swash project)
@@ -187,9 +199,9 @@ class TransCanvas3D extends JPanel implements AncestorListener {
      * double buffer enable : false<br>
      * stereo enable : false<br>
      */
-    public TransCanvas3D() {
+    public TransCanvas3D(boolean trans) {// kenji trans追加
         this(null, GraphicsEnvironment.getLocalGraphicsEnvironment().
-                getDefaultScreenDevice());
+                getDefaultScreenDevice(),trans);// kenji
     }
 
     /**
@@ -199,8 +211,8 @@ class TransCanvas3D extends JPanel implements AncestorListener {
      * @param device the screen graphics device that will be used to construct
      *        a GraphicsConfiguration.
      */
-    public TransCanvas3D(GraphicsDevice device) {
-        this(null, device);
+    public TransCanvas3D(GraphicsDevice device,boolean trans) {// kenji trans追加
+        this(null, device,trans);//kenji
     }
 
     /**
@@ -215,9 +227,9 @@ class TransCanvas3D extends JPanel implements AncestorListener {
      *        GraphicsConfiguration. The stereo and doublebuffer properties
      *        are forced to UNNECESSARY.
      */
-    public TransCanvas3D(GraphicsConfigTemplate3D template) {
+    public TransCanvas3D(GraphicsConfigTemplate3D template,boolean trans) {// kenji trans追加
         this(template, GraphicsEnvironment.getLocalGraphicsEnvironment().
-                getDefaultScreenDevice());
+                getDefaultScreenDevice(),trans);//kenji
     }
 
     /**
@@ -230,9 +242,10 @@ class TransCanvas3D extends JPanel implements AncestorListener {
      * @param device the screen graphics device that will be used to construct
      *        a GraphicsConfiguration in conjunction with the template.
      */
-    public TransCanvas3D(GraphicsConfigTemplate3D template, GraphicsDevice device) {
+    public TransCanvas3D(GraphicsConfigTemplate3D template, GraphicsDevice device,boolean trans) {// kenji trans追加
         this.device = device;
         this.template = new GraphicsConfigTemplate3D();
+        this.trans = trans;//kenji
 
         if (template != null) {
             // Clone template (it would be easier if GCT3D were cloneable)
@@ -260,7 +273,8 @@ class TransCanvas3D extends JPanel implements AncestorListener {
         // so that key events and such can be received.
         setFocusable(true);
 
-        setOpaque(false);//kenji おれが追加．
+        if (trans==true)//kenji おれが追加．
+            setOpaque(false);
     }
     //kenji
     public void addNotify() {
@@ -390,9 +404,11 @@ class TransCanvas3D extends JPanel implements AncestorListener {
         this.canvas.startRenderer();
 
         //kenji
-        DepthComponentFloat dcf = new DepthComponentFloat(width,height);
-        this.canvas.zRaster = new Raster(new Point3f(0.0f,0.0f,0.0f),
-                                         Raster.RASTER_DEPTH,0,0,width,height,null,dcf);
+        if (trans) {
+            DepthComponentFloat dcf = new DepthComponentFloat(width,height);
+            this.canvas.zRaster = new Raster(new Point3f(0.0f,0.0f,0.0f),
+                                             Raster.RASTER_DEPTH,0,0,width,height,null,dcf);
+        }
     }
 
     /**
@@ -444,65 +460,77 @@ class TransCanvas3D extends JPanel implements AncestorListener {
 
         // Wait for and display image if TransCanvas3D was added to an ancestor
         if (hasBeenAdded) {
-            //if ((false == canvas.canvasCrashed) &&
-            //        (true == canvas.isRendererRunning())) {
-            //    //            System.err.println("paintComponentWaitforSwap");
-            //    canvas.waitForSwap();
-            //
-            //    //            System.err.println("wait is over");
-            //}
-
-            //kenji
-            if (true == canvas.canvasCrashed)
-                return;
-            this.canvas.stopRenderer();
-            this.canvas.waitForOffScreenRendering();
+            if (trans) { // kenji
+                //透明化が必要な時の処理。こうしないと非常にちらつく
+                if (true == canvas.canvasCrashed)
+                    return;
+                canvas.stopRenderer();
+                canvas.waitForOffScreenRendering();
+            } else {
+                //もともとの処理
+                if ((false == canvas.canvasCrashed) &&
+                        (true == canvas.isRendererRunning())) {
+                    //System.err.println("paintComponentWaitforSwap");
+                    canvas.waitForSwap();
+                    //System.err.println("wait is over");
+                }
+            }
 
             if (null != canvas.bi) {
                 // can eventually be null if the canvas did not send the result in the desired timeframe
                 // for first render. In that case, we don't paint and keep the background as-is.
 
-                //kenji
-                int w = canvas.bi.getWidth();
-                int h = canvas.bi.getHeight();
-                if (depthData==null)
-                    depthData = new float[w*h];
-                if (w*h!=depthData.length)
-                    depthData = new float[w*h];
-                DepthComponentFloat dcf = (DepthComponentFloat)canvas.zRaster.getDepthComponent();
-                dcf.getDepthData(depthData);
-                for (int x=0;x<w;x++) {
-                    for (int y=0;y<h;y++) {
-                        if (depthData[x+w*y]>0.999) {
-                            canvas.bi.setRGB(x,y,0);
+                //kenji 背景の透明化の処理
+                if (trans) {
+                    int w = canvas.bi.getWidth();
+                    int h = canvas.bi.getHeight();
+                    if (depthData==null)
+                        depthData = new float[w*h];
+                    if (w*h!=depthData.length)
+                        depthData = new float[w*h];
+                    DepthComponentFloat dcf = (DepthComponentFloat)canvas.zRaster.getDepthComponent();
+                    dcf.getDepthData(depthData);
+                    for (int x=0;x<w;x++) {
+                        for (int y=0;y<h;y++) {
+                            if (depthData[x+w*y]>0.999) {
+                                canvas.bi.setRGB(x,y,0);
+                            }
                         }
                     }
                 }
-                //kenji
-                if ((widget!=null)&&(widget.universe!=null)) {
-                    Graphics2D g2 = canvas.bi.createGraphics();
+
+                //kenji フィルタ処理
+                BufferedImage bi = canvas.bi;
+                for (A3Filter f : filters) {
+                    bi = f.filter(bi);
+                }
+
+                //kenji Component2Dの処理
+                if ((canvasIF!=null)&&(canvasIF.getVirtualUniverse()!=null)) {
+                    Graphics2D g2 = bi.createGraphics();
                     g2.setComposite(AlphaComposite.Src);
-                    Component2D cs[] = widget.universe.getComponents2D().toArray(new Component2D[0]);
+                    Component2D cs[] = canvasIF.getVirtualUniverse().getComponents2D().toArray(new Component2D[0]);
                     for (Component2D c: cs) {
-                        c.calPhysicalZ(widget);
+                        c.calPhysicalZ(canvasIF);
                     }
                     Arrays.sort(cs,Component2DComparator.comparator);
                     for (Component2D c : cs) {
                         if (c.z>0.0)
                             continue;
-                        c.paint(g2,widget);
+                        c.paint(g2,canvasIF);
                     }
                     if (Component2D.advertisement!=null) {
-                        Component2D.advertisement.paint(g2,widget);
+                        Component2D.advertisement.paint(g2,canvasIF);
                     }
                     //g2.flush(true);
                     g2.dispose();
                 }
 
+                //kenji オフスクリーンバッファの描画
                 ((Graphics2D)g).setComposite(AlphaComposite.Src);
-                g.drawImage(canvas.bi, 0, 0, getWidth(), getHeight(), null);
+                g.drawImage(bi, 0, 0, getWidth(), getHeight(), null);
 
-                //FPSのための計算 kenji
+                //kenji FPSのための計算 kenji
                 fpsCounter++;
                 long l = System.currentTimeMillis()-fpsStartTime;
                 if (l>1000) {
@@ -512,7 +540,9 @@ class TransCanvas3D extends JPanel implements AncestorListener {
                 }
             }
 
-            this.canvas.startRenderer(); //kenji
+            if (trans) { //kenji
+                canvas.startRenderer();
+            }
         }
     }
 
@@ -523,6 +553,19 @@ class TransCanvas3D extends JPanel implements AncestorListener {
     int getFPS() {
         return fps;
     }
+
+    //kenji
+    ArrayList<A3Filter> filters = new ArrayList<A3Filter>();
+    public void addA3Filter(A3Filter f) {
+        filters.add(f);
+    }
+    public void delA3Filter(A3Filter f) {
+        filters.remove(f);
+    }
+    public void delAllA3Filter() {
+        filters.clear();
+    }
+
     /**
      * Redirects event to canvas and to superclass.
      *
@@ -697,7 +740,7 @@ class TransCanvas3D extends JPanel implements AncestorListener {
      * Java 3D. It is remote controlled through TransCanvas3D and is modified to be
      * able to tell the lightweight component when refreshes are needed.
      */
-    static class InternalCanvas3D extends Canvas3D
+    class InternalCanvas3D extends Canvas3D// kenji classの前のstaticを取った
           implements AutoOffScreenCanvas3D { // どうやら，これを実装するとJava3Dが特別扱いをするっぽい． //kenji
         private static final long serialVersionUID = 1L;//kenji
         // These two constants define the maximum amount of time
@@ -780,7 +823,8 @@ class TransCanvas3D extends JPanel implements AncestorListener {
             imageReadyBis = false;
             waitingForSwap = false;
             addNotifyFlag = false;
-            gc3d = this.getGraphicsContext3D(); //kenji
+            if (trans) //kenji
+                gc3d = this.getGraphicsContext3D();
         }
 
         /**
@@ -827,7 +871,8 @@ class TransCanvas3D extends JPanel implements AncestorListener {
         synchronized public void postSwap() {
             if (true == isRendererRunning()) { // as weird as it can look, there can be postswaps without rendered running. (?!!) Anyway, in that case we should not refresh.
                 bi = getOffScreenBuffer().getImage();
-                gc3d.readRaster(zRaster); //kenji
+                if (trans) //kenji
+                    gc3d.readRaster(zRaster);
                 imageReadyBis = true;
 
                 if (false == waitingForSwap) {
