@@ -136,7 +136,7 @@ public class Util {
     }
 
     /**
-     * 行列を四元数をに変換するメソッドです。javax.vecmathパッケージにも
+     * 行列を四元数に変換するメソッドです(Matrix3d版)。javax.vecmathパッケージにも
      * 同じ機能の変換メソッドが用意されていますが、少し気になるところがあるので
      * 自前実装を作りました。
      */
@@ -197,6 +197,68 @@ public class Util {
         return q;
     }
 
+    /**
+     * 行列を四元数に変換するメソッドです(Matrix3f版)。javax.vecmathパッケージにも
+     * 同じ機能の変換メソッドが用意されていますが、少し気になるところがあるので
+     * 自前実装を作りました。
+     */
+    public static Quat4d matrix2quat(Matrix3f m) {
+        //http://marupeke296.com/DXG_No58_RotQuaternionTrans.html
+
+        // 最大成分を検索
+        double elem[] = new double[4]; // 0:x, 1:y, 2:z, 3:w
+        elem[0] =  m.m00 - m.m11 - m.m22 + 1.0;
+        elem[1] = -m.m00 + m.m11 - m.m22 + 1.0;
+        elem[2] = -m.m00 - m.m11 + m.m22 + 1.0;
+        elem[3] =  m.m00 + m.m11 + m.m22 + 1.0;
+
+        int biggestIndex = 0;
+        for (int i=1;i<4;i++) {
+            if (elem[i] > elem[biggestIndex])
+                biggestIndex = i;
+        }
+
+        if (elem[biggestIndex]<0.0) {
+            //引数の行列に間違いあり！
+            //どうすりゃ良いのかわからない．
+            return null;
+        }
+
+        // 最大要素の値を算出
+        double v = sqrt( elem[biggestIndex] ) * 0.5;
+        double mult = 0.25 / v;
+        Quat4d q = new Quat4d();
+
+        switch (biggestIndex) {
+        case 0: // x
+            q.x = v;
+            q.y = (m.m10 + m.m01) * mult;
+            q.z = (m.m02 + m.m20) * mult;
+            q.w = (m.m21 - m.m12) * mult;
+            break;
+        case 1: // y
+            q.x = (m.m10 + m.m01) * mult;
+            q.y = v;
+            q.z = (m.m21 + m.m12) * mult;
+            q.w = (m.m02 - m.m20) * mult;
+            break;
+        case 2: // z
+            q.x = (m.m02 + m.m20) * mult;
+            q.y = (m.m21 + m.m12) * mult;
+            q.z = v;
+            q.w = (m.m10 - m.m01) * mult;
+            break;
+        case 3: // w
+            q.x = (m.m21 - m.m12) * mult;
+            q.y = (m.m02 - m.m20) * mult;
+            q.z = (m.m10 - m.m01) * mult;
+            q.w = v;
+            break;
+        }
+
+        return q;
+    }
+
     /**
      * 点aを点bに移す原点中心の回転を表す四元数を作成します。
      * a,bの長さが異なっていれば作成される四元数には拡大縮小率も含みます。
@@ -635,6 +697,7 @@ System.out.println("totalTriangles:"+totalTriangles);
             ;
         } else {
             System.out.println("GAHA6");
+            System.out.println(n.getClass().getName());
         }
         return idx;
     }
